package com.game.business.service;

import java.util.List;
import com.game.business.domain.AppUsersCharge;
import com.baomidou.mybatisplus.extension.service.IService;
import com.game.business.vo.AppRechargeConfigVo;

/**
 * 充值记录Service接口
 *
 * @author game
 * @date 2024-06-18
 */
public interface IAppUsersChargeService extends IService<AppUsersCharge> {
    /**
     * 查询充值记录
     *
     * @param id 充值记录主键
     * @return 充值记录
     */
    public AppUsersCharge selectAppUsersChargeById(Long id);

    /**
     * 查询充值记录列表
     *
     * @param appUsersCharge 充值记录
     * @return 充值记录集合
     */
    public List<AppUsersCharge> selectAppUsersChargeList(AppUsersCharge appUsersCharge);

    /**
     * 新增充值记录
     *
     * @param appUsersCharge 充值记录
     * @return 结果
     */
    public int insertAppUsersCharge(AppUsersCharge appUsersCharge);

    /**
     * 修改充值记录
     *
     * @param appUsersCharge 充值记录
     * @return 结果
     */
    public int updateAppUsersCharge(AppUsersCharge appUsersCharge);

    /**
     * 批量删除充值记录
     *
     * @param ids 需要删除的充值记录主键集合
     * @return 结果
     */
    public int deleteAppUsersChargeByIds(Long[] ids);

    /**
     * 删除充值记录信息
     *
     * @param id 充值记录主键
     * @return 结果
     */
    public int deleteAppUsersChargeById(Long id);


    /**
     * 按日期查询下级用户充值列表
     *
     * */
    public List<AppUsersCharge> getChargeList(Long userId,String beginTime,String endTime);

    /**
     * 查询返佣比例
     * */
    public double isChargeToday(Long userId,int coinType);

    AppUsersCharge selectByOrderNo(String orderNo);

    Double sumCharge(Long userId);

    AppRechargeConfigVo getRechargeConfig();
}